OC.L10N.register(
    "circles",
    {
    "Personal" : "Personīgs",
    "System" : "Sistēma",
    "Visible" : "Redzams",
    "Open" : "Atvērt",
    "Invite" : "Uzaicināt",
    "Password protected" : "Aizsargāts ar paroli",
    "Hidden" : "Paslēpts",
    "Local" : "Lokāls",
    "Root" : "Root",
    "Federated" : "Federated",
    "Contact" : "Kontakts",
    "Circle" : "Loks",
    "Admin" : "Admin",
    "Owner" : "Īpašnieks",
    "Open »%s«" : "Atvērt »%s«",
    "Accept" : "Akceptēt",
    "%s" : "%s",
    "No files in here" : "Šeit nav datņu",
    "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
    "Name" : "Vārds",
    "Size" : "Izmērs",
    "Modified" : "Mainīts",
    "now" : "šobrīd"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
